import glob
import re

from .store import Store


def main():
    from .config import config

    store = Store(
        path=config.db,
        collection=config.collection,
    )
    if config.files:
        files = config.files

        if "*" in files[0]:
            files = [f for f in glob.iglob(files[0])]

        for filename in files:
            store.add_file(filename, parent_id="") # parent_id = <paperless-id>

    elif config.query:
        docs = store.search(config.query, config.n_results)
        for doc in docs:
            parent_id = doc["parent_id"]

            printable = re.sub(r"[\s\n\t]+", " ", doc["content"][:130]).strip()
            print(f"""{parent_id}({doc["order"]}): {doc["meta"]["title"]}\n\tcontent="{printable}"... """)
        return
    else:
        print("No input provided. Please provide a file or query.")


if __name__ == "__main__":
    main()
